@@ -59,5 +59,26 @@ SQUIDCEXTERN int gethostname(char *, int);
 #define __FUNCTION__ ""
 #endif
 
+/* Bug 2500: Solaris 10/11 require s6_addr* defines. */
+//#define s6_addr8   _S6_un._S6_u8
+//#define s6_addr16  _S6_un._S6_u16
+#define s6_addr32  _S6_un._S6_u32
+
+/* Bug 3057: Solaris 9 defines struct addrinfo with size_t instead of socklen_t
+ *           this causes binary incompatibility on 64-bit systems.
+ *  Fix this by bundling a copy of the OpenSolaris 10 netdb.h to use instead.
+ */
+#if defined(__sparcv9)
+#include "compat/os/opensolaris_10_netdb.h"
+#endif
+
+/* Solaris lacks paths.h by default */
+#if HAVE_PATHS_H
+#include <paths.h>
+#endif
+#if !defined(_PATH_DEVNULL)
+#define _PATH_DEVNULL "/dev/null"
+#endif
+
 #endif /* _SQUID_SOLARIS_ */
 #endif /* SQUID_OS_SOALRIS_H */
