@@ -36,11 +36,14 @@
  *
  * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
  */
+
+#include "config.h"
+
 #ifndef DELAYPOOL_H
 #define DELAYPOOL_H
 
-#if USE_DELAY_POOLS
-#include "squid-old.h"
+#if DELAY_POOLS
+#include "squid.h"
 #include "CompositePoolNode.h"
 
 class StoreEntry;
@@ -71,5 +74,5 @@ private:
     CompositePoolNode::Pointer theComposite_;
 };
 
-#endif /* USE_DELAY_POOLS */
+#endif
 #endif /* DELAYPOOL_H */
