@@ -1,5 +1,7 @@
 
 /*
+ * $Id$
+ *
  * DEBUG: section 77    Delay Pools
  * AUTHOR: Robert Collins <robertc@squid-cache.org>
  *
@@ -33,10 +35,10 @@
  * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
  */
 
-#include "squid.h"
+#include "config.h"
 
-#if USE_DELAY_POOLS
-#include "comm/Connection.h"
+#if DELAY_POOLS
+#include "squid.h"
 #include "DelayTagged.h"
 #include "NullDelayId.h"
 #include "Store.h"
