@@ -44,7 +44,7 @@
  * per storedir it should work just fine.
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "AIODiskFile.h"
 #include "AIODiskIOStrategy.h"
 #include "DiskIO/IORequestor.h"
@@ -86,7 +86,7 @@ void
 AIODiskFile::open(int flags, mode_t mode, RefCount<IORequestor> callback)
 {
     /* Simulate async calls */
-#if _SQUID_WINDOWS_
+#ifdef _SQUID_WIN32_
     fd = aio_open(path.termedBuf(), flags);
 #else
     fd = file_open(path.termedBuf() , flags);
@@ -99,7 +99,7 @@ AIODiskFile::open(int flags, mode_t mode, RefCount<IORequestor> callback)
         error(true);
     } else {
         closed = false;
-        ++store_open_disk_fd;
+        store_open_disk_fd++;
         debugs(79, 3, HERE << ": opened FD " << fd);
     }
 
@@ -159,7 +159,7 @@ AIODiskFile::read(ReadRequest *request)
     qe->aq_e_aiocb.aio_buf =  request->buf;
 
     /* Account */
-    ++ strategy->aq.aq_numpending;
+    strategy->aq.aq_numpending++;
 
     /* Initiate aio */
     if (aio_read(&qe->aq_e_aiocb) < 0) {
@@ -232,9 +232,11 @@ void
 AIODiskFile::close ()
 {
     assert (!closed);
-#if _SQUID_WINDOWS_
+#ifdef _SQUID_WIN32_
+
     aio_close(fd);
 #else
+
     file_close(fd);
 #endif
 
