@@ -34,16 +34,14 @@
  * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
  */
 
-#include "squid-old.h"
+#include "squid.h"
 
-#include "DiskThreadsDiskFile.h"
+#include "CacheManager.h"
 #include "DiskThreadsIOStrategy.h"
-#include "fde.h"
-#include "mgr/Registration.h"
-#include "StatCounters.h"
+#include "DiskThreadsDiskFile.h"
 /* for statfs */
 #include "Store.h"
-
+#include "fde.h"
 
 void
 DiskThreadsIOStrategy::init(void)
@@ -67,8 +65,9 @@ DiskThreadsIOStrategy::init(void)
 void
 DiskThreadsIOStrategy::registerWithCacheManager(void)
 {
-    Mgr::RegisterAction("squidaio_counts", "Async IO Function Counters",
-                        aioStats, 0, 1);
+    CacheManager::GetInstance()->
+    registerAction("squidaio_counts", "Async IO Function Counters",
+                   aioStats, 0, 1);
 }
 
 void
@@ -94,7 +93,7 @@ DiskThreadsIOStrategy::callback()
     int retval = 0;
 
     assert(initialised);
-    ++squidaio_counts.check_callback;
+    squidaio_counts.check_callback++;
 
     for (;;) {
         if ((resultp = squidaio_poll_done()) == NULL)
@@ -167,7 +166,7 @@ DiskThreadsIOStrategy::callback()
         if (ctrlp->operation == _AIO_READ)
             squidaio_xfree(ctrlp->bufp, ctrlp->len);
 
-        squidaio_ctrl_pool->freeOne(ctrlp);
+        squidaio_ctrl_pool->free(ctrlp);
     }
 
     return retval;
@@ -190,10 +189,7 @@ DiskThreadsIOStrategy::sync()
     debugs(32, 2, "aioSync: done");
 }
 
-DiskThreadsIOStrategy::DiskThreadsIOStrategy() :
-        initialised(false),
-        squidaio_ctrl_pool(NULL)
-{}
+DiskThreadsIOStrategy::DiskThreadsIOStrategy() :  initialised (false) {}
 
 void
 DiskThreadsIOStrategy::aioStats(StoreEntry * sentry)
@@ -258,15 +254,9 @@ DiskThreadsIOStrategy::newFile (char const *path)
     return new DiskThreadsDiskFile (path, this);
 }
 
-bool
-DiskThreadsIOStrategy::unlinkdUseful() const
-{
-    return false;
-}
-
 void
 DiskThreadsIOStrategy::unlinkFile(char const *path)
 {
-    ++statCounter.syscalls.disk.unlinks;
+    statCounter.syscalls.disk.unlinks++;
     aioUnlink(path, NULL, NULL);
 }
