@@ -36,6 +36,9 @@
 class Packer;
 class String;
 
+/* for SQUIDCEXTERN */
+#include "config.h"
+
 /* for http_status and protocol_t */
 #include "enums.h"
 
