@@ -66,14 +66,14 @@ public:
 
     /// these space-related methods assume no growth and allow 0-termination
     char *space() { return buf + size; } // space to add data
-    char *space(mb_size_t required) { if (size + required >= capacity) grow(size + required +1); return buf + size; } // space to add data
+    char *space(mb_size_t required) { if (size + required > capacity) grow(size + required); return buf + size; } // space to add data
 
     mb_size_t spaceSize() const;
 
     /**
      * Whether the buffer contains any data space available.
-     \retval true	if data can be added to the buffer
-     \retval false	if the buffer is full
+     \retval true	if data can be added to teh buffer
+     \retval false	if teh buffer is full
      */
     bool hasSpace() const { return size+1 < capacity; }
 
@@ -169,7 +169,7 @@ public:
 #endif
 };
 
-#if _USE_INLINE_
+#ifdef _USE_INLINE_
 #include "MemBuf.cci"
 #endif
 
