@@ -33,10 +33,9 @@
  *
  */
 
-#include "squid-old.h"
-#include "base/TextException.h"
-#include "mgr/Registration.h"
+#include "squid.h"
 #include "Store.h"
+#include "TextException.h"
 
 int
 String::psize() const
@@ -130,7 +129,7 @@ String::allocAndFill(const char *str, int len)
     assert(this && str);
     allocBuffer(len + 1);
     len_ = len;
-    memcpy(buf_, str, len);
+    xmemcpy(buf_, str, len);
     buf_[len] = '\0';
     PROF_stop(StringAllocAndFill);
 }
@@ -200,10 +199,10 @@ String::append(const char *str, int len)
         snew.allocBuffer(snew.len_ + 1);
 
         if (len_)
-            memcpy(snew.buf_, rawBuf(), len_);
+            xmemcpy(snew.buf_, rawBuf(), len_);
 
         if (len)
-            memcpy(snew.buf_ + len_, str, len);
+            xmemcpy(snew.buf_ + len_, str, len);
 
         snew.buf_[snew.len_] = '\0';
 
@@ -248,8 +247,7 @@ String::absorb(String &old)
 String
 String::substr(String::size_type from, String::size_type to) const
 {
-//    Must(from >= 0 && from < size());
-    Must(from < size());
+    Must(from >= 0 && from < size());
     Must(to > 0 && to <= size());
     Must(to > from);
 
@@ -282,19 +280,23 @@ ptrcmp(C const &lhs, C const &rhs)
 StringRegistry::StringRegistry()
 {
 #if DEBUGSTRINGS
-    Mgr::RegisterAction("strings",
-                        "Strings in use in squid", Stat, 0, 1);
+    CacheManager::GetInstance()->registerAction("strings",
+            "Strings in use in squid", Stat, 0, 1);
 #endif
 }
 
 void
-StringRegistry::add(String const *entry)
+
+StringRegistry::add
+(String const *entry)
 {
     entries.insert(entry, ptrcmp);
 }
 
 void
-StringRegistry::remove(String const *entry)
+
+StringRegistry::remove
+(String const *entry)
 {
     entries.remove(entry, ptrcmp);
 }
@@ -363,7 +365,7 @@ strwordtok(char *buf, char **t)
         goto error;
 
     while (*p && xisspace(*p))
-        ++p;
+        p++;
 
     if (!*p)
         goto error;
@@ -374,7 +376,7 @@ strwordtok(char *buf, char **t)
         switch (ch) {
 
         case '\\':
-            ++p;
+            p++;
 
             switch (*p) {
 
@@ -395,36 +397,33 @@ strwordtok(char *buf, char **t)
 
             }
 
-            *d = ch;
-            ++d;
+            *d++ = ch;
 
             if (ch)
-                ++p;
+                p++;
 
             break;
 
         case '"':
             quoted = !quoted;
 
-            ++p;
+            p++;
 
             break;
 
         default:
             if (!quoted && xisspace(*p)) {
-                ++p;
+                p++;
                 goto done;
             }
 
-            *d = *p;
-            ++d;
-            ++p;
+            *d++ = *p++;
             break;
         }
     }
 
 done:
-    *d = '\0';
+    *d++ = '\0';
 
 error:
     *t = (char *) p;
@@ -493,6 +492,6 @@ String::rfind(char const ch) const
 
 
 
-#if !_USE_INLINE_
+#ifndef _USE_INLINE_
 #include "String.cci"
 #endif
