@@ -41,7 +41,8 @@ typedef enum {
     LOG_TCP_HIT,
     LOG_TCP_MISS,
     LOG_TCP_REFRESH_UNMODIFIED, // refresh from origin revalidated existing entry
-    LOG_TCP_REFRESH_FAIL,       // refresh from origin failed
+    LOG_TCP_REFRESH_FAIL_OLD,   // refresh from origin failed, stale reply sent
+    LOG_TCP_REFRESH_FAIL_ERR,   // refresh from origin failed, error forwarded
     LOG_TCP_REFRESH_MODIFIED,   // refresh from origin replaced existing entry
     LOG_TCP_CLIENT_REFRESH_MISS,
     LOG_TCP_IMS_HIT,
@@ -81,6 +82,7 @@ typedef enum {
     ERR_FORWARDING_DENIED,
     ERR_NO_RELAY,
     ERR_ZERO_SIZE_OBJECT,
+    ERR_PRECONDITION_FAILED,
     ERR_FTP_DISABLED,
     ERR_FTP_FAILURE,
     ERR_URN_RESOLVE,
@@ -101,6 +103,7 @@ typedef enum {
     ERR_INVALID_RESP,
     ERR_ICAP_FAILURE,
     ERR_UNSUP_HTTPVERSION,     /* HTTP version is not supported */
+    ERR_GATEWAY_FAILURE,
     ERR_MAX
 } err_type;
 
@@ -143,7 +146,9 @@ typedef enum {
     CC_MAX_AGE,
     CC_S_MAXAGE,
     CC_MAX_STALE,
+    CC_MIN_FRESH,
     CC_ONLY_IF_CACHED,
+    CC_STALE_IF_ERROR,
     CC_OTHER,
     CC_ENUM_END
 } http_hdr_cc_type;
