@@ -1,11 +1,13 @@
 #define SQUID_UNIT_TEST 1
 
 #include "squid.h"
-#include <stdexcept>
-
 #include "testACLMaxUserIP.h"
 #include "auth/AclMaxUserIp.h"
 
+#if HAVE_STDEXCEPT
+#include <stdexcept>
+#endif
+
 CPPUNIT_TEST_SUITE_REGISTRATION( testACLMaxUserIP );
 
 
