@@ -1,9 +1,6 @@
 #define SQUID_UNIT_TEST 1
 
 #include "squid.h"
-
-#if USE_AUTH
-
 #include "testAuth.h"
 #include "auth/Gadgets.h"
 #include "auth/UserRequest.h"
@@ -14,16 +11,16 @@
 CPPUNIT_TEST_SUITE_REGISTRATION( testAuth );
 CPPUNIT_TEST_SUITE_REGISTRATION( testAuthConfig );
 CPPUNIT_TEST_SUITE_REGISTRATION( testAuthUserRequest );
-#if HAVE_AUTH_MODULE_BASIC
+#ifdef HAVE_AUTH_MODULE_BASIC
 CPPUNIT_TEST_SUITE_REGISTRATION( testAuthBasicUserRequest );
 #endif
-#if HAVE_AUTH_MODULE_DIGEST
+#ifdef HAVE_AUTH_MODULE_DIGEST
 CPPUNIT_TEST_SUITE_REGISTRATION( testAuthDigestUserRequest );
 #endif
-#if HAVE_AUTH_MODULE_NTLM
+#ifdef HAVE_AUTH_MODULE_NTLM
 CPPUNIT_TEST_SUITE_REGISTRATION( testAuthNTLMUserRequest );
 #endif
-#if HAVE_AUTH_MODULE_NEGOTIATE
+#ifdef HAVE_AUTH_MODULE_NEGOTIATE
 CPPUNIT_TEST_SUITE_REGISTRATION( testAuthNegotiateUserRequest );
 #endif
 
@@ -62,22 +59,22 @@ static
 AuthConfig *
 getConfig(char const *type_str)
 {
-    Auth::authConfig &config = Auth::TheConfig;
+    Vector<AuthConfig *> &config = Config.authConfiguration;
     /* find a configuration for the scheme */
-    AuthConfig *scheme = AuthConfig::Find(type_str);
+    AuthConfig *scheme = AuthConfig::Find (type_str);
 
     if (scheme == NULL) {
         /* Create a configuration */
-        AuthScheme::Pointer theScheme = AuthScheme::Find(type_str);
+        AuthScheme *theScheme;
 
-        if (theScheme == NULL) {
+        if ((theScheme = AuthScheme::Find(type_str)) == NULL) {
             return NULL;
             //fatalf("Unknown authentication scheme '%s'.\n", type_str);
         }
 
         config.push_back(theScheme->createConfig());
         scheme = config.back();
-        assert(scheme);
+        assert (scheme);
     }
 
     return scheme;
@@ -87,7 +84,7 @@ static
 void
 setup_scheme(AuthConfig *scheme, char const **params, unsigned param_count)
 {
-    Auth::authConfig &config = Auth::TheConfig;
+    Vector<AuthConfig *> &config = Config.authConfiguration;
 
     for (unsigned position=0; position < param_count; position++) {
         char *param_str=xstrdup(params[position]);
@@ -107,7 +104,7 @@ fake_auth_setup()
 
     Mem::Init();
 
-    Auth::authConfig &config = Auth::TheConfig;
+    Vector<AuthConfig *> &config = Config.authConfiguration;
 
     char const *digest_parms[]= {"program /home/robertc/install/squid/libexec/digest_pw_auth /home/robertc/install/squid/etc/digest.pwd",
                                  "realm foo"
@@ -158,8 +155,8 @@ testAuthConfig::create()
     Debug::Levels[29]=9;
     fake_auth_setup();
 
-    for (AuthScheme::iterator i = AuthScheme::GetSchemes().begin(); i != AuthScheme::GetSchemes().end(); ++i) {
-        AuthUserRequest::Pointer authRequest = AuthConfig::CreateAuthUser(find_proxy_auth((*i)->type()));
+    for (AuthScheme::const_iterator i = AuthScheme::Schemes().begin(); i != AuthScheme::Schemes().end(); ++i) {
+        AuthUserRequest *authRequest = AuthConfig::CreateAuthUser(find_proxy_auth((*i)->type()));
         CPPUNIT_ASSERT(authRequest != NULL);
     }
 }
@@ -177,16 +174,15 @@ testAuthUserRequest::scheme()
     Debug::Levels[29]=9;
     fake_auth_setup();
 
-    for (AuthScheme::iterator i = AuthScheme::GetSchemes().begin(); i != AuthScheme::GetSchemes().end(); ++i) {
+    for (AuthScheme::const_iterator i = AuthScheme::Schemes().begin(); i != AuthScheme::Schemes().end(); ++i) {
         // create a user request
         // check its scheme matches *i
-        AuthUserRequest::Pointer authRequest = AuthConfig::CreateAuthUser(find_proxy_auth((*i)->type()));
+        AuthUserRequest *authRequest = AuthConfig::CreateAuthUser(find_proxy_auth((*i)->type()));
         CPPUNIT_ASSERT_EQUAL(authRequest->scheme(), *i);
     }
 }
 
-#if HAVE_AUTH_MODULE_BASIC
-#include "auth/basic/basicUserRequest.h"
+#ifdef HAVE_AUTH_MODULE_BASIC
 #include "auth/basic/auth_basic.h"
 /* AuthBasicUserRequest::AuthBasicUserRequest works
  */
@@ -201,15 +197,18 @@ testAuthBasicUserRequest::construction()
 void
 testAuthBasicUserRequest::username()
 {
-    AuthUserRequest::Pointer temp = new AuthBasicUserRequest();
+    AuthBasicUserRequest();
+    AuthBasicUserRequest *temp=new AuthBasicUserRequest();
     BasicUser *basic_auth=new BasicUser(AuthConfig::Find("basic"));
     basic_auth->username("John");
     temp->user(basic_auth);
+    basic_auth->addRequest(temp);
     CPPUNIT_ASSERT_EQUAL(0, strcmp("John", temp->username()));
+    delete temp;
 }
 #endif /* HAVE_AUTH_MODULE_BASIC */
 
-#if HAVE_AUTH_MODULE_DIGEST
+#ifdef HAVE_AUTH_MODULE_DIGEST
 #include "auth/digest/auth_digest.h"
 /* AuthDigestUserRequest::AuthDigestUserRequest works
  */
@@ -224,15 +223,18 @@ testAuthDigestUserRequest::construction()
 void
 testAuthDigestUserRequest::username()
 {
-    AuthUserRequest::Pointer temp = new AuthDigestUserRequest();
-    DigestUser *duser=new DigestUser(AuthConfig::Find("digest"));
-    duser->username("John");
-    temp->user(duser);
+    AuthDigestUserRequest();
+    AuthDigestUserRequest *temp=new AuthDigestUserRequest();
+    DigestUser *user=new DigestUser(AuthConfig::Find("digest"));
+    user->username("John");
+    temp->user(user);
+    user->addRequest(temp);
     CPPUNIT_ASSERT_EQUAL(0, strcmp("John", temp->username()));
+    delete temp;
 }
 #endif /* HAVE_AUTH_MODULE_DIGEST */
 
-#if HAVE_AUTH_MODULE_NTLM
+#ifdef HAVE_AUTH_MODULE_NTLM
 #include "auth/ntlm/auth_ntlm.h"
 /* AuthNTLMUserRequest::AuthNTLMUserRequest works
  */
@@ -247,15 +249,18 @@ testAuthNTLMUserRequest::construction()
 void
 testAuthNTLMUserRequest::username()
 {
-    AuthUserRequest::Pointer temp = new AuthNTLMUserRequest();
-    NTLMUser *nuser=new NTLMUser(AuthConfig::Find("ntlm"));
-    nuser->username("John");
-    temp->user(nuser);
+    AuthNTLMUserRequest();
+    AuthNTLMUserRequest *temp=new AuthNTLMUserRequest();
+    NTLMUser *user=new NTLMUser(AuthConfig::Find("ntlm"));
+    user->username("John");
+    temp->user(user);
+    user->addRequest(temp);
     CPPUNIT_ASSERT_EQUAL(0, strcmp("John", temp->username()));
+    delete temp;
 }
 #endif /* HAVE_AUTH_MODULE_NTLM */
 
-#if HAVE_AUTH_MODULE_NEGOTIATE
+#ifdef HAVE_AUTH_MODULE_NEGOTIATE
 #include "auth/negotiate/auth_negotiate.h"
 /* AuthNegotiateUserRequest::AuthNegotiateUserRequest works
  */
@@ -270,12 +275,14 @@ testAuthNegotiateUserRequest::construction()
 void
 testAuthNegotiateUserRequest::username()
 {
-    AuthUserRequest::Pointer temp = new AuthNegotiateUserRequest();
-    NegotiateUser *nuser=new NegotiateUser(AuthConfig::Find("negotiate"));
-    nuser->username("John");
-    temp->user(nuser);
+    AuthNegotiateUserRequest();
+    AuthNegotiateUserRequest *temp=new AuthNegotiateUserRequest();
+    NegotiateUser *user=new NegotiateUser(AuthConfig::Find("negotiate"));
+    user->username("John");
+    temp->user(user);
+    user->addRequest(temp);
     CPPUNIT_ASSERT_EQUAL(0, strcmp("John", temp->username()));
+    delete temp;
 }
 
 #endif /* HAVE_AUTH_MODULE_NEGOTIATE */
-#endif /* USE_AUTH */
