@@ -31,7 +31,6 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  */
-#define SQUID_UNIT_TEST 1
 #include "config.h"
 
 #if 0
@@ -49,6 +48,15 @@
 #include "acl/Checklist.h"
 #endif
 
+/* Stub routines */
+void
+shut_down(int)
+{}
+
+void
+reconfigure(int)
+{}
+
 SQUIDCEXTERN void httpHeaderPutStr(HttpHeader * hdr, http_hdr_type type, const char *str)
 {
     fatal ("dummy function\n");
