@@ -1,5 +1,7 @@
 
 /*
+ * $Id$
+ *
  * DEBUG: section 80    WCCP Support
  * AUTHOR: Glenn Chisholm
  *
@@ -31,13 +33,10 @@
  *
  */
 #include "squid.h"
+#include "comm.h"
+#include "event.h"
 
 #if USE_WCCP
-#include "comm.h"
-#include "comm/Connection.h"
-#include "comm/Loops.h"
-#include "event.h"
-#include "SquidConfig.h"
 
 #define WCCP_PORT 2048
 #define WCCP_REVISION 0
@@ -60,7 +59,7 @@ struct wccp_here_i_am_t {
 };
 
 struct wccp_cache_entry_t {
-    struct in_addr ip_addr;  // WCCP on-the-wire in 32-bit IPv4-only.
+    struct in_addr ip_addr;
     int revision;
     char hash[WCCP_HASH_SIZE];
     int reserved;
@@ -92,7 +91,7 @@ static int last_id;
 static int last_assign_buckets_change;
 static unsigned int number_caches;
 
-static Ip::Address local_ip;
+static IpAddress local_ip;
 
 static PF wccpHandleUdp;
 static int wccpLowestIP(void);
@@ -128,6 +127,7 @@ wccpInit(void)
 void
 wccpConnectionOpen(void)
 {
+    struct addrinfo *router = NULL, *local = NULL;
     debugs(80, 5, "wccpConnectionOpen: Called");
 
     if (Config.Wccp.router.IsAnyAddr()) {
@@ -136,12 +136,12 @@ wccpConnectionOpen(void)
     }
 
     if ( !Config.Wccp.router.SetIPv4() ) {
-        debugs(80, DBG_CRITICAL, "WCCPv1 Disabled. Router " << Config.Wccp.router << " is not an IPv4 address.");
+        debugs(1, 1, "WCCPv1 Disabled. Router " << Config.Wccp.router << " is not IPv4.");
         return;
     }
 
     if ( !Config.Wccp.address.SetIPv4() ) {
-        debugs(80, DBG_CRITICAL, "WCCPv1 Disabled. Local address " << Config.Wccp.address << " is not an IPv4 address.");
+        debugs(1, 1, "WCCPv1 Disabled. Local address " << Config.Wccp.address << " is not IPv4.");
         return;
     }
 
@@ -157,31 +157,37 @@ wccpConnectionOpen(void)
     if (theWccpConnection < 0)
         fatal("Cannot open WCCP Port");
 
-    Comm::SetSelect(theWccpConnection, COMM_SELECT_READ, wccpHandleUdp, NULL, 0);
+    commSetSelect(theWccpConnection,
+                  COMM_SELECT_READ,
+                  wccpHandleUdp,
+                  NULL,
+                  0);
 
-    debugs(80, DBG_IMPORTANT, "Accepting WCCPv1 messages on " << Config.Wccp.address << ", FD " << theWccpConnection << ".");
+    debugs(80, 1, "Accepting WCCPv1 messages on " << Config.Wccp.address << ", FD " << theWccpConnection << ".");
 
-    // Sadly WCCP only does IPv4
+    Config.Wccp.router.GetAddrInfo(router,AF_INET);
 
-    struct sockaddr_in router;
-    Config.Wccp.router.GetSockAddr(router);
-    if (connect(theWccpConnection, (struct sockaddr*)&router, sizeof(router)))
+    if (connect(theWccpConnection, router->ai_addr, router->ai_addrlen))
         fatal("Unable to connect WCCP out socket");
 
-    struct sockaddr_in local;
-    memset(&local, '\0', sizeof(local));
-    socklen_t slen = sizeof(local);
-    if (getsockname(theWccpConnection, (struct sockaddr*)&local, &slen))
+    Config.Wccp.router.FreeAddrInfo(router);
+
+    Config.Wccp.address.InitAddrInfo(local);
+
+    if (getsockname(theWccpConnection, local->ai_addr, &local->ai_addrlen))
         fatal("Unable to getsockname on WCCP out socket");
 
-    local_ip = local;
+    local_ip = *local;
+
+    Config.Wccp.address.FreeAddrInfo(local);
 }
 
+
 void
 wccpConnectionClose(void)
 {
     if (theWccpConnection > -1) {
-        debugs(80, DBG_IMPORTANT, "FD " << theWccpConnection << " Closing WCCPv1 socket");
+        debugs(80, 1, "FD " << theWccpConnection << " Closing WCCPv1 socket");
         comm_close(theWccpConnection);
         theWccpConnection = -1;
     }
@@ -197,12 +203,13 @@ wccpConnectionClose(void)
 static void
 wccpHandleUdp(int sock, void *not_used)
 {
-    Ip::Address from;
+
+    IpAddress from;
     int len;
 
     debugs(80, 6, "wccpHandleUdp: Called.");
 
-    Comm::SetSelect(sock, COMM_SELECT_READ, wccpHandleUdp, NULL, 0);
+    commSetSelect(sock, COMM_SELECT_READ, wccpHandleUdp, NULL, 0);
 
     memset(&wccp_i_see_you, '\0', sizeof(wccp_i_see_you));
 
@@ -232,7 +239,7 @@ wccpHandleUdp(int sock, void *not_used)
         return;
 
     if (ntohl(wccp_i_see_you.number) > WCCP_ACTIVE_CACHES) {
-        debugs(80, DBG_IMPORTANT, "Ignoring WCCP_I_SEE_YOU from " <<
+        debugs(80, 1, "Ignoring WCCP_I_SEE_YOU from " <<
                from << " with number of caches set to " <<
                (int) ntohl(wccp_i_see_you.number));
 
@@ -278,7 +285,7 @@ wccpLowestIP(void)
      * We sanity checked wccp_i_see_you.number back in wccpHandleUdp()
      */
 
-    for (loop = 0; loop < (unsigned) ntohl(wccp_i_see_you.number); ++loop) {
+    for (loop = 0; loop < (unsigned) ntohl(wccp_i_see_you.number); loop++) {
         assert(loop < WCCP_ACTIVE_CACHES);
 
         if (local_ip > wccp_i_see_you.wccp_cache_entry[loop].ip_addr)
@@ -340,28 +347,26 @@ wccpAssignBuckets(void)
 
     buckets = buf + wab_len + cache_len;
 
-    memset(wccp_assign_bucket, '\0', sizeof(*wccp_assign_bucket));
+    memset(wccp_assign_bucket, '\0', sizeof(wccp_assign_bucket));
 
     memset(buckets, 0xFF, WCCP_BUCKETS);
 
     buckets_per_cache = WCCP_BUCKETS / number_caches;
 
-    for (loop = 0; loop < number_caches; ++loop) {
+    for (loop = 0; loop < number_caches; loop++) {
         int i;
-        memcpy(&caches[loop],
-               &wccp_i_see_you.wccp_cache_entry[loop].ip_addr,
-               sizeof(*caches));
+        xmemcpy(&caches[loop],
+                &wccp_i_see_you.wccp_cache_entry[loop].ip_addr,
+                sizeof(*caches));
 
-        for (i = 0; i < buckets_per_cache; ++i) {
+        for (i = 0; i < buckets_per_cache; i++) {
             assert(bucket < WCCP_BUCKETS);
-            buckets[bucket] = loop;
-            ++bucket;
+            buckets[bucket++] = loop;
         }
     }
 
     while (bucket < WCCP_BUCKETS) {
-        buckets[bucket] = number_caches - 1;
-        ++bucket;
+        buckets[bucket++] = number_caches - 1;
     }
 
     wccp_assign_bucket->type = htonl(WCCP_ASSIGN_BUCKET);
